from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .MixinSignEditScreen import MixinSignEditScreen
from .MixinHungerManager import MixinHungerManager
from .MixinRecipeBookWidget import MixinRecipeBookWidget
from .MixinFontManager import MixinFontManager
from .MixinChunkSelection import MixinChunkSelection
from .IMixinEntity import IMixinEntity
from .MixinLivingEntity import MixinLivingEntity
from .MixinMinecraftClient import MixinMinecraftClient
from .MixinPackedIntegerArray import MixinPackedIntegerArray
from .MixinClientPlayerEntity import MixinClientPlayerEntity
from .MixinClientPlayNetworkHandler import MixinClientPlayNetworkHandler
from .MixinMerchantEntity import MixinMerchantEntity
from .MixinDisconnectedScreen import MixinDisconnectedScreen
from .MixinSplashOverlay import MixinSplashOverlay
from .MixinTrueTypeFont import MixinTrueTypeFont
from .MixinClientPlayerInteractionManager import MixinClientPlayerInteractionManager
from .MixinHorseScreen import MixinHorseScreen
from .MixinCreativeInventoryScreen import MixinCreativeInventoryScreen
from .MixinPalettedContainer import MixinPalettedContainer
from .MixinChatHud import MixinChatHud
from .MixinLoomScreen import MixinLoomScreen
from .MixinHandledScreen import MixinHandledScreen
from .MixinItemCooldownManager import MixinItemCooldownManager
from .MixinSimpleOption import MixinSimpleOption
from .MixinClientWorld import MixinClientWorld
from .MixinSoundSystem import MixinSoundSystem
from .MixinTranslationStorage import MixinTranslationStorage
from .MixinPlayerListHud import MixinPlayerListHud
from .MixinBeaconScreen import MixinBeaconScreen
from .MixinItemCooldownEntry import MixinItemCooldownEntry
from .MixinFontStorage import MixinFontStorage
from .MixinBossBarHud import MixinBossBarHud
from .MixinEntity import MixinEntity
from .MixinPlayerEntity import MixinPlayerEntity
from .MixinRecipeBookResults import MixinRecipeBookResults
from .MixinMerchantScreen import MixinMerchantScreen
from .MixinStyleSerializer import MixinStyleSerializer
from .MixinScreen import MixinScreen
from .MixinPalettedContainerData import MixinPalettedContainerData

File = TypeVar["java.io.File"]

