from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .GroupFilter_CountMatchFilter import GroupFilter_CountMatchFilter
from .Util import Util
from .History import History
from .OptionsField import OptionsField
from .TextOverlay import TextOverlay
from .CharCompareFilter import CharCompareFilter
from .LongField import LongField
from .CommandManager import CommandManager
from .IRecipeBookResults import IRecipeBookResults
from .Button import Button
from .IDraw2D import IDraw2D
from .TextInput import TextInput
from .Prism_typescript import Prism_typescript
from .DoubleField import DoubleField
from .BaseScriptContext_ScriptAssertionError import BaseScriptContext_ScriptAssertionError
from .IChunkSection import IChunkSection
from .ClientConfigV2 import ClientConfigV2
from .IItemCooldownManager import IItemCooldownManager
from .Prism_groovy import Prism_groovy
from .ColorMapSetting import ColorMapSetting
from .IPalettedContainer import IPalettedContainer
from .ColorMapSetting_ColorEntry import ColorMapSetting_ColorEntry
from .PlayerInput import PlayerInput
from .IFontManager import IFontManager
from .IBeaconScreen import IBeaconScreen
from .IRecipeBookWidget import IRecipeBookWidget
from .StringifyFilter import StringifyFilter
from .IHorseScreen import IHorseScreen
from .WrappedClassInstance_MethodSigParts import WrappedClassInstance_MethodSigParts
from .IFilter import IFilter
from .IPackedIntegerArray import IPackedIntegerArray
from .RenderCommon_Item import RenderCommon_Item
from .ChatHistoryManager import ChatHistoryManager
from .Inventory import Inventory
from .Sorting_SortByTriggerName import Sorting_SortByTriggerName
from .BaseWrappedException_HostLocation import BaseWrappedException_HostLocation
from .TranslationUtil import TranslationUtil
from .IntField import IntField
from .BaseListener import BaseListener
from .AbstractSettingContainer import AbstractSettingContainer
from .SelectorDropdownOverlay import SelectorDropdownOverlay
from .ServiceContainer import ServiceContainer
from .FileChooser_fileObj import FileChooser_fileObj
from .BlockStateFilter import BlockStateFilter
from .EnchantInventory import EnchantInventory
from .IMerchantScreen import IMerchantScreen
from .KeyMacrosScreen import KeyMacrosScreen
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .History_TabLinesKeepCursor import History_TabLinesKeepCursor
from .History_HistoryStep import History_HistoryStep
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .Scrollbar import Scrollbar
from .BooleanCompareFilter import BooleanCompareFilter
from .FileChooser_sortFile import FileChooser_sortFile
from .History_Add import History_Add
from .EventRegistry import EventRegistry
from .Websocket import Websocket
from .ScriptTrigger import ScriptTrigger
from .ServiceListTopbar import ServiceListTopbar
from .Event import Event
from .KeyListener import KeyListener
from .BasicFilter import BasicFilter
from .ExtensionLoader import ExtensionLoader
from .VillagerInventory import VillagerInventory
from .BaseWrappedException import BaseWrappedException
from .PerExecLanguageLibrary import PerExecLanguageLibrary
from .NumberCompareFilter import NumberCompareFilter
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
from .ClassBuilder import ClassBuilder
from .CustomClickEvent import CustomClickEvent
from .TextBuilder import TextBuilder
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .IContainerParent import IContainerParent
from .PositionCommon_Pos2D import PositionCommon_Pos2D
from .StringMapSetting_StringEntry import StringMapSetting_StringEntry
from .BaseWrappedException_GuestLocation import BaseWrappedException_GuestLocation
from .FileChooser import FileChooser
from .Sorting_SortByEnabled import Sorting_SortByEnabled
from .PrimitiveSettingGroup import PrimitiveSettingGroup
from .LibraryBuilder import LibraryBuilder
from .Draw3D import Draw3D
from .Prism_kotlin import Prism_kotlin
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .IClientPlayerEntity import IClientPlayerEntity
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .TickSync import TickSync
from .EventChooser_EventObj import EventChooser_EventObj
from .StringField import StringField
from .BaseScriptContext_SleepRunnable import BaseScriptContext_SleepRunnable
from .AutoCompleteSuggestor import AutoCompleteSuggestor
from .MovementDummy import MovementDummy
from .IOverlayParent import IOverlayParent
from .RenderCommon_Text import RenderCommon_Text
from .ScriptScreen import ScriptScreen
from .IMinecraftClient import IMinecraftClient
from .WorldScannerBuilder import WorldScannerBuilder
from .Draw2D import Draw2D
from .FloatField import FloatField
from .PositionCommon import PositionCommon
from .StringMapSetting import StringMapSetting
from .FJsMacros_EventAndContext import FJsMacros_EventAndContext
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
from .CancelScreen_RTCSort import CancelScreen_RTCSort
from .AboutOverlay import AboutOverlay
from .NoStyleCodeCompiler import NoStyleCodeCompiler
from .CheckBoxContainer import CheckBoxContainer
from .ListContainer import ListContainer
from .DocletReplaceParams import DocletReplaceParams
from .PerLanguageLibrary import PerLanguageLibrary
from .Extension_ExtMatch import Extension_ExtMatch
from .BaseScriptContext import BaseScriptContext
from .Pair import Pair
from .ProxyBuilder import ProxyBuilder
from .IInventory import IInventory
from .IScreen import IScreen
from .TextPrompt import TextPrompt
from .Prism_json import Prism_json
from .ServiceScreen import ServiceScreen
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .Extension import Extension
from .ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder import ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder
from .Mappings import Mappings
from .BaseLibrary import BaseLibrary
from .ICategoryTreeParent import ICategoryTreeParent
from .ServiceTrigger import ServiceTrigger
from .WrappedScript import WrappedScript
from .StringCompareFilter_FilterMethod import StringCompareFilter_FilterMethod
from .CommandNodeAccessor import CommandNodeAccessor
from .PrioryFiFoTaskQueue import PrioryFiFoTaskQueue
from .Draw3D_Box import Draw3D_Box
from .ClassWrapperFilter import ClassWrapperFilter
from .RenderCommon_Rect import RenderCommon_Rect
from .IMerchantEntity import IMerchantEntity
from .WorldScanner import WorldScanner
from .DefaultCodeCompiler import DefaultCodeCompiler
from .BlockFilter import BlockFilter
from .Draw3D_Surface import Draw3D_Surface
from .HTTPRequest import HTTPRequest
from .ISignEditScreen import ISignEditScreen
from .FileField import FileField
from .OrFilter import OrFilter
from .FKeyBind_KeyTracker import FKeyBind_KeyTracker
from .RenderCommon import RenderCommon
from .IAdvancedFilter import IAdvancedFilter
from .LibraryRegistry import LibraryRegistry
from .TickBasedEvents import TickBasedEvents
from .ILoomScreen import ILoomScreen
from .NotFilter import NotFilter
from .SettingsOverlay import SettingsOverlay
from .HTTPRequest_Response import HTTPRequest_Response
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
from .Prism_python import Prism_python
from .MacroScreen import MacroScreen
from .ExtensionClassLoader import ExtensionClassLoader
from .ConfigFolder import ConfigFolder
from .ICompare import ICompare
from .IBossBarHud import IBossBarHud
from .History_TabLines import History_TabLines
from .Mappings_MethodData import Mappings_MethodData
from .Profile import Profile
from .BaseEventRegistry import BaseEventRegistry
from .GroupFilter_NoneMatchFilter import GroupFilter_NoneMatchFilter
from .MacroListTopbar import MacroListTopbar
from .RenderCommon_Image import RenderCommon_Image
from .BooleanField import BooleanField
from .Prism_regex import Prism_regex
from .IPlayerListHud import IPlayerListHud
from .Prism_lua import Prism_lua
from .ClassBuilder_FieldBuilder_FieldInitializerBuilder import ClassBuilder_FieldBuilder_FieldInitializerBuilder
from .EventListener import EventListener
from .BaseProfile import BaseProfile
from .TPSData import TPSData
from .ConfirmOverlay import ConfirmOverlay
from .SynchronizedWeakHashSet import SynchronizedWeakHashSet
from .GroupFilter import GroupFilter
from .Neighbor import Neighbor
from .Draw3D_Line import Draw3D_Line
from .StringHashTrie import StringHashTrie
from .ConfigManager import ConfigManager
from .EventLockWatchdog import EventLockWatchdog
from .AndFilter import AndFilter
from .OverlayContainer import OverlayContainer
from .PositionCommon_Plane3D import PositionCommon_Plane3D
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .Mappings_ClassData import Mappings_ClassData
from .BaseLanguage import BaseLanguage
from .CategoryTreeContainer import CategoryTreeContainer
from .MultiElementContainer import MultiElementContainer
from .BeaconInventory import BeaconInventory
from .AutoCompleteSuggestion import AutoCompleteSuggestion
from .AnnotatedCheckBox import AnnotatedCheckBox
from .MacroContainer import MacroContainer
from .PositionCommon_Vec2D import PositionCommon_Vec2D
from .ProxyBuilder_ProxyReference import ProxyBuilder_ProxyReference
from .IChatHud import IChatHud
from .History_Replace import History_Replace
from .GroupFilter_AllMatchFilter import GroupFilter_AllMatchFilter
from .XorFilter import XorFilter
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
from .StringCompareFilter import StringCompareFilter
from .EditorScreen import EditorScreen
from .Sorting_SortByFileName import Sorting_SortByFileName
from .BaseScreen import BaseScreen
from .IItemCooldownEntry import IItemCooldownEntry
from .Prism_ruby import Prism_ruby
from .JsMacros import JsMacros
from .EventMacrosScreen import EventMacrosScreen
from .Core import Core
from .CoreConfigV2 import CoreConfigV2
from .SelectCursor import SelectCursor
from .History_Remove import History_Remove
from .PositionCommon_Vec3D import PositionCommon_Vec3D
from .Websocket_Disconnected import Websocket_Disconnected
from .Prism_javascript import Prism_javascript
from .AbstractSettingField import AbstractSettingField
from .DocletReplaceReturn import DocletReplaceReturn
from .Option import Option
from .MethodWrapper import MethodWrapper
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .Library import Library
from .Prism import Prism
from .ProfileSetting import ProfileSetting
from .FileMapSetting import FileMapSetting
from .FileMapSetting_FileEntry import FileMapSetting_FileEntry
from .WrappedClassInstance import WrappedClassInstance
from .Mappings_MappedClass import Mappings_MappedClass
from .FJsMacros_ScriptEventListener import FJsMacros_ScriptEventListener
from .LoomInventory import LoomInventory
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .CancelScreen import CancelScreen
from .GroupFilter_AnyMatchFilter import GroupFilter_AnyMatchFilter
from .PerExecLibrary import PerExecLibrary
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
from .ServiceManager import ServiceManager
from .MovementQueue import MovementQueue
from .EventChooser import EventChooser
from .OptionType import OptionType
from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .TextStyleCompiler import TextStyleCompiler
from .Sorting import Sorting
from .FileHandler import FileHandler
from .ProfileSetting_ProfileEntry import ProfileSetting_ProfileEntry
from .IEventListener import IEventListener
from .Prism_clike import Prism_clike
from .IPalettedContainerData import IPalettedContainerData
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder
from .History_ShiftLine import History_ShiftLine
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder
from .BossBarConsumer import BossBarConsumer
from .ScriptCodeCompiler import ScriptCodeCompiler
from .CommandBuilder import CommandBuilder
from .RunningContextContainer import RunningContextContainer

File = TypeVar["java.io.File"]

